operator_dict = {
   "azami": {
      "name": "Azami",
      "safename": "azami",
      "year": "Y7S1",
      "health": 2,
      "armor": 2,
      "unit": "UNAFFILIATED",
      "country_code": "JP",
      "roles": ["Area Denial"],
      "side": "defender",
      "id": "",
      "icon_url": "https://i.imgur.com/AmyLoc5.png",
      "unique_stats": [
         {
            "id": "operatorpvp_azami_something",
            "name": "Kiba Barrier something"
         }
      ]
   },
   "thorn": {
      "name": "Thorn",
      "safename": "thorn",
      "year": "Y6S4",
      "health": 2,
      "armor": 2,
      "unit": "GARDA SÍOCHÁNA",
      "country_code": "IE",
      "roles": [
         "Anchor",
         "Secure"
      ],
      "side": "defender",
      "id": "",
      "icon_url": "https://i.imgur.com/w5DB6xs.png",
      "unique_stats": [
         {
            "id": "operatorpvp_thorn_something",
            "name": "Razorbloom something"
         }
      ]
   },
   "osa": {
      "name": "Osa",
      "safename": "osa",
      "year": "Y6S3",
      "health": 2,
      "armor": 2,
      "unit": "NIGHTHAVEN",
      "country_code": "HR",
      "roles": [
         "Intel Gatherer",
         "Area Denial",
         "Anti Roam"
      ],
      "side": "attacker",
      "id": "6:17",
      "icon_url": "https://i.imgur.com/WjvbwYD.png",
      "unique_stats": [
         {
            "id": "operatorpvp_osa_shieldsdeployed",
            "name": "TALON-8 Clear Shields deployed"
         }
      ]
   },
   "thunderbird": {
      "name": "Thunderbird",
      "safename": "thunderbird",
      "year": "Y6S2",
      "health": 1,
      "armor": 3,
      "unit": "UNAFFILIATED",
      "country_code": "",
      "roles": [
         "Secure",
         "Roam",
         "Buff"
      ],
      "side": "defender",
      "id": "1:1C",
      "icon_url": "https://i.imgur.com/21vn9y7.png",
      "unique_stats": [
         {
            "id": "operatorpvp_thunderbird_heals",
            "name": "KÓNA Station heals"
         }
      ]
   },
   "flores": {
      "name": "Flores",
      "safename": "flores",
      "year": "Y6S1",
      "health": 2,
      "armor": 2,
      "unit": "UNAFFILIATED",
      "country_code": "AR",
      "roles": [
         "Soft Breach",
         "Disable",
         "Area Denial",
         "Back Line"
      ],
      "side": "attacker",
      "id": "3:18",
      "icon_url": "https://i.imgur.com/1wBdB2q.png",
      "unique_stats": [
         {
            "id": "operatorpvp_flores_gadgetdestroywithrceratero",
            "name": "Gadgets Destroyed with RCE"
         }
      ]
   },
   "aruni": {
      "name": "Aruni",
      "safename": "aruni",
      "year": "Y5S4",
      "health": 2,
      "armor": 2,
      "unit": "NIGHTHAVEN",
      "country_code": "TH",
      "roles": [
         "Secure",
         "Intel Gatherer",
         "Anchor"
      ],
      "side": "defender",
      "id": "5:17",
      "icon_url": "https://i.imgur.com/PhCM38D.png",
      "unique_stats": [
         {
            "id": "operatorpvp_aruni_gatesdeployed",
            "name": "Surya Gates Deployed"
         }
      ]
   },
   "tachanka": {
      "name": "Tachanka",
      "safename": "tachanka",
      "year": "Y0S0",
      "health": 3,
      "armor": 1,
      "unit": "SPETSNAZ",
      "country_code": "RU",
      "roles": [
         "Anchor",
         "Covering Fire",
         "Shield"
      ],
      "side": "defender",
      "id": "5:4",
      "icon_url": "https://i.imgur.com/VTUCIZH.png",
      "unique_stats": [
         {
            "id": "operatorpvp_tachanka_turretkill",
            "name": "Mounted LMG Kills"
         },
         {
            "id": "operatorpvp_tachanka_turretdeployed",
            "name": "Mounted LMG Deployed"
         }
      ]
   },
   "frost": {
      "name": "Frost",
      "safename": "frost",
      "year": "Y1S1",
      "health": 2,
      "armor": 2,
      "unit": "JTF2",
      "country_code": "CA",
      "roles": [
         "Crowd Control",
         "Trap"
      ],
      "side": "defender",
      "id": "3:6",
      "icon_url": "https://i.imgur.com/FTbAE33.png",
      "unique_stats": [
         {
            "id": "operatorpvp_frost_dbno",
            "name": "Enemies Caught in Welcome Mats"
         }
      ]
   },
   "oryx": {
      "name": "Oryx",
      "safename": "oryx",
      "year": "Y5S1",
      "health": 2,
      "armor": 2,
      "unit": "UNAFFILIATED",
      "country_code": "JO",
      "roles": [
         "Roam",
         "Soft Breach"
      ],
      "side": "defender",
      "id": "2:18",
      "icon_url": "https://i.imgur.com/BdJnmYf.png",
      "unique_stats": [
         {
            "id": "operatorpvp_oryx_killsafterdash",
            "name": "Kills after Remah Dashes"
         }
      ]
   },
   "melusi": {
      "name": "Melusi",
      "safename": "melusi",
      "year": "Y5S2",
      "health": 1,
      "armor": 3,
      "unit": "ITF",
      "country_code": "SA",
      "roles": [
         "Crowd Control",
         "Intel Gatherer",
         "Secure"
      ],
      "side": "defender",
      "id": "2:1A",
      "icon_url": "https://i.imgur.com/7BNXQnr.png",
      "unique_stats": [
         {
            "id": "operatorpvp_melusi_sloweddown",
            "name": "Attackers slowed by Banshee"
         }
      ]
   },
   "buck": {
      "name": "Buck",
      "safename": "buck",
      "year": "Y1S1",
      "health": 2,
      "armor": 2,
      "unit": "JTF2",
      "country_code": "CA",
      "roles": [
         "Flank",
         "Soft Breach"
      ],
      "side": "attacker",
      "id": "2:6",
      "icon_url": "https://i.imgur.com/u9slUlM.png",
      "unique_stats": [
         {
            "id": "operatorpvp_buck_kill",
            "name": "Kills with the Skeleton Key"
         }
      ]
   },
   "zofia": {
      "name": "Zofia",
      "safename": "zofia",
      "year": "Y2S4",
      "health": 2,
      "armor": 2,
      "unit": "G.R.O.",
      "country_code": "PL",
      "roles": [
         "Anti Roam",
         "Crowd Control",
         "Disable",
         "Flank",
         "Soft Breach"
      ],
      "side": "attacker",
      "id": "3:C",
      "icon_url": "https://i.imgur.com/AMOYwMJ.png",
      "unique_stats": [
         {
            "id": "operatorpvp_concussiongrenade_detonate",
            "name": "Concussion Grenades Detonated"
         }
      ]
   },
   "echo": {
      "name": "Echo",
      "safename": "echo",
      "year": "Y1S4",
      "health": 3,
      "armor": 1,
      "unit": "S.A.T.",
      "country_code": "JP",
      "roles": [
         "Anchor",
         "Crowd Control",
         "Intel Gatherer",
         "Secure"
      ],
      "side": "defender",
      "id": "3:9",
      "icon_url": "https://i.imgur.com/OMNe9qB.png",
      "unique_stats": [
         {
            "id": "operatorpvp_echo_enemy_sonicburst_affected",
            "name": "Enemies Disoriented by Yokai"
         }
      ]
   },
   "dokkaebi": {
      "name": "Dokkaebi",
      "safename": "dokkaebi",
      "year": "Y2S4",
      "health": 2,
      "armor": 2,
      "unit": "707TH SMB",
      "country_code": "SK",
      "roles": [
         "Anti Roam",
         "Flank",
         "Intel Denier",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "2:D",
      "icon_url": "https://i.imgur.com/iVLOHr2.png",
      "unique_stats": [
         {
            "id": "operatorpvp_phoneshacked",
            "name": "Phones Hacked"
         }
      ]
   },
   "caveira": {
      "name": "Caveira",
      "safename": "caveira",
      "year": "Y1S3",
      "health": 1,
      "armor": 3,
      "unit": "BOPE",
      "country_code": "BR",
      "roles": [
         "Intel Denier",
         "Intel Gatherer",
         "Roam"
      ],
      "side": "defender",
      "id": "3:8",
      "icon_url": "https://i.imgur.com/IeYRobc.png",
      "unique_stats": [
         {
            "id": "operatorpvp_caveira_interrogations",
            "name": "Successful Interrogations Performed"
         }
      ]
   },
   "wamai": {
      "name": "Wamai",
      "safename": "wamai",
      "year": "Y4S4",
      "health": 2,
      "armor": 2,
      "unit": "NIGHTHAVEN",
      "country_code": "KE",
      "roles": [
         "Anchor",
         "Secure"
      ],
      "side": "defender",
      "id": "3:17",
      "icon_url": "https://i.imgur.com/bFRCKTJ.png",
      "unique_stats": [
         {
            "id": "operatorpvp_wamai_gadgetdestroybymagnet",
            "name": "Projectiles Captured"
         }
      ]
   },
   "ying": {
      "name": "Ying",
      "safename": "ying",
      "year": "Y2S3",
      "health": 2,
      "armor": 2,
      "unit": "S.D.U",
      "country_code": "HK",
      "roles": [
         "Crowd Control",
         "Front Line"
      ],
      "side": "attacker",
      "id": "2:B",
      "icon_url": "https://i.imgur.com/BHUvTt4.png",
      "unique_stats": [
         {
            "id": "operatorpvp_dazzler_gadget_detonate",
            "name": "Candela Devices Detonated"
         }
      ]
   },
   "nomad": {
      "name": "Nomad",
      "safename": "nomad",
      "year": "Y3S4",
      "health": 2,
      "armor": 2,
      "unit": "GIGR",
      "country_code": "MA",
      "roles": [
         "Anti Roam",
         "Crowd Control",
         "Trap"
      ],
      "side": "attacker",
      "id": "2:11",
      "icon_url": "https://i.imgur.com/2I6OWIz.png",
      "unique_stats": [
         {
            "id": "operatorpvp_nomad_airjabdetonate",
            "name": "Airjabs Detonated"
         }
      ]
   },
   "rook": {
      "name": "Rook",
      "safename": "rook",
      "year": "Y0S0",
      "health": 3,
      "armor": 1,
      "unit": "GIGN",
      "country_code": "FR",
      "roles": [
         "Anchor",
         "Buff"
      ],
      "side": "defender",
      "id": "3:3",
      "icon_url": "https://i.imgur.com/UQK1UNc.png",
      "unique_stats": [
         {
            "id": "operatorpvp_rook_armortakenteammate",
            "name": "Armor Plate Taken by Teammates"
         },
         {
            "id": "operatorpvp_rook_armortakenourself",
            "name": "Armors Taken for Self"
         },
         {
            "id": "operatorpvp_rook_armorboxdeployed",
            "name": "Armor Crates Deployed"
         }
      ]
   },
   "nokk": {
      "name": "Nøkk",
      "safename": "nokk",
      "year": "Y4S2",
      "health": 2,
      "armor": 2,
      "unit": "JAEGER CORPS",
      "country_code": "DK",
      "roles": [
         "Flank",
         "Intel Denier"
      ],
      "side": "attacker",
      "id": "2:13",
      "icon_url": "https://i.imgur.com/oleTyHs.png",
      "unique_stats": [
         {
            "id": "operatorpvp_nokk_observationtooldeceived",
            "name": "Observation Tools Deceived"
         }
      ]
   },
   "mozzie": {
      "name": "Mozzie",
      "safename": "mozzie",
      "year": "Y4S1",
      "health": 2,
      "armor": 2,
      "unit": "SASR",
      "country_code": "AN",
      "roles": [
         "Intel Denier",
         "Intel Gatherer",
         "Secure"
      ],
      "side": "defender",
      "id": "2:12",
      "icon_url": "https://i.imgur.com/yrFXGCn.png",
      "unique_stats": [
         {
            "id": "operatorpvp_mozzie_droneshacked",
            "name": "Drones Hacked"
         }
      ]
   },
   "montagne": {
      "name": "Montagne",
      "safename": "montagne",
      "year": "Y0S0",
      "health": 3,
      "armor": 1,
      "unit": "GIGN",
      "country_code": "FR",
      "roles": [
         "Shield"
      ],
      "side": "attacker",
      "id": "5:3",
      "icon_url": "https://i.imgur.com/bzzVRTU.png",
      "unique_stats": [
         {
            "id": "operatorpvp_montagne_shieldblockdamage",
            "name": "Bullets Blocked by Extended Shield"
         }
      ]
   },
   "mira": {
      "name": "Mira",
      "safename": "mira",
      "year": "Y2S1",
      "health": 3,
      "armor": 1,
      "unit": "G.E.O.",
      "country_code": "ES",
      "roles": [
         "Anchor",
         "Intel Gatherer",
         "Secure"
      ],
      "side": "defender",
      "id": "3:A",
      "icon_url": "https://i.imgur.com/gOnJqiF.png",
      "unique_stats": [
         {
            "id": "operatorpvp_black_mirror_gadget_deployed",
            "name": "Black Mirror Deployed"
         }
      ]
   },
   "maverick": {
      "name": "Maverick",
      "safename": "maverick",
      "year": "Y3S3",
      "health": 1,
      "armor": 3,
      "unit": "THE UNIT",
      "country_code": "US",
      "roles": [
         "Back Line",
         "Disable",
         "Flank",
         "Hard Breach"
      ],
      "side": "attacker",
      "id": "2:10",
      "icon_url": "https://i.imgur.com/8hXt5z6.png",
      "unique_stats": [
         {
            "id": "operatorpvp_maverick_wallbreached",
            "name": "Walls Breached With Torch"
         }
      ]
   },
   "lion": {
      "name": "Lion",
      "safename": "lion",
      "year": "Y3S1",
      "health": 2,
      "armor": 2,
      "unit": "GIGN",
      "country_code": "FR",
      "roles": [
         "Anti Roam",
         "Back Line",
         "Crowd Control",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "3:E",
      "icon_url": "https://i.imgur.com/0zCtOUO.png",
      "unique_stats": [
         {
            "id": "operatorpvp_tagger_tagdevice_spot",
            "name": "Enemies Detected by EE-ONE-D"
         }
      ]
   },
   "iana": {
      "name": "Iana",
      "safename": "iana",
      "year": "Y5S1",
      "health": 2,
      "armor": 2,
      "unit": "REU",
      "country_code": "NL",
      "roles": [
         "Intel Denier",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "2:19",
      "icon_url": "https://i.imgur.com/bk77LOt.png",
      "unique_stats": [
         {
            "id": "operatorpvp_iana_killsafterreplicator",
            "name": "Kills after using Replicators"
         }
      ]
   },
   "kali": {
      "name": "Kali",
      "safename": "kali",
      "year": "Y4S4",
      "health": 2,
      "armor": 2,
      "unit": "NIGHTHAVEN",
      "country_code": "IN",
      "roles": [
         "Back Line",
         "Covering Fire",
         "Disable"
      ],
      "side": "attacker",
      "id": "2:17",
      "icon_url": "https://i.imgur.com/sQGypuE.png",
      "unique_stats": [
         {
            "id": "operatorpvp_kali_gadgetdestroywithexplosivelance",
            "name": "Gadgets Destroyed with the LV"
         }
      ]
   },
   "kaid": {
      "name": "Kaid",
      "safename": "kaid",
      "year": "Y3S4",
      "health": 3,
      "armor": 1,
      "unit": "GIGR",
      "country_code": "MA",
      "roles": [
         "Anchor",
         "Anti Hard Breach",
         "Secure"
      ],
      "side": "defender",
      "id": "3:11",
      "icon_url": "https://i.imgur.com/Du1aa9i.png",
      "unique_stats": [
         {
            "id": "operatorpvp_kaid_electroclawelectrify",
            "name": "Electroclaws Successfully Deployed"
         }
      ]
   },
   "jager": {
      "name": "Jäger",
      "safename": "jager",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "GSG9",
      "country_code": "DE",
      "roles": [
         "Roam",
         "Secure"
      ],
      "side": "defender",
      "id": "4:5",
      "icon_url": "https://i.imgur.com/Y8EjdSy.png",
      "unique_stats": [
         {
            "id": "operatorpvp_jager_gadgetdestroybycatcher",
            "name": "Gadget Destroyed by ADS"
         }
      ]
   },
   "gridlock": {
      "name": "Gridlock",
      "safename": "gridlock",
      "year": "Y4S1",
      "health": 3,
      "armor": 1,
      "unit": "SASR",
      "country_code": "AN",
      "roles": [
         "Anti Roam",
         "Area Denial",
         "Crowd Control"
      ],
      "side": "attacker",
      "id": "3:12",
      "icon_url": "https://i.imgur.com/WHkIm3H.png",
      "unique_stats": [
         {
            "id": "operatorpvp_gridlock_traxdeployed",
            "name": "Trax Deployed"
         }
      ]
   },
   "glaz": {
      "name": "Glaz",
      "safename": "glaz",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SPETSNAZ",
      "country_code": "RU",
      "roles": [
         "Back Line",
         "Covering Fire",
         "Soft Breach"
      ],
      "side": "attacker",
      "id": "2:4",
      "icon_url": "https://i.imgur.com/7vFvnxZ.png",
      "unique_stats": [
         {
            "id": "operatorpvp_glaz_sniperkill",
            "name": "Sniper Kills"
         },
         {
            "id": "operatorpvp_glaz_sniperpenetrationkill",
            "name": "Penetration Sniper Kills"
         }
      ]
   },
   "goyo": {
      "name": "Goyo",
      "safename": "goyo",
      "year": "Y4S3",
      "health": 2,
      "armor": 2,
      "unit": "FES",
      "country_code": "MX",
      "roles": [
         "Area Denial",
         "Secure"
      ],
      "side": "defender",
      "id": "2:15",
      "icon_url": "https://i.imgur.com/tYPrtCH.png",
      "unique_stats": [
         {
            "id": "operatorpvp_goyo_volcandetonate",
            "name": "Volcán Detonated by Your Team"
         }
      ]
   },
   "fuze": {
      "name": "Fuze",
      "safename": "fuze",
      "year": "Y0S0",
      "health": 3,
      "armor": 1,
      "unit": "SPETSNAZ",
      "country_code": "RU",
      "roles": [
         "Area Denial",
         "Disable",
         "Flank"
      ],
      "side": "attacker",
      "id": "3:4",
      "icon_url": "https://i.imgur.com/xsVA73Z.png",
      "unique_stats": [
         {
            "id": "operatorpvp_fuze_clusterchargekill",
            "name": "Cluster Charge Kills"
         }
      ]
   },
   "finka": {
      "name": "Finka",
      "safename": "finka",
      "year": "Y3S1",
      "health": 2,
      "armor": 2,
      "unit": "SPETSNAZ",
      "country_code": "RU",
      "roles": [
         "Back Line",
         "Buff"
      ],
      "side": "attacker",
      "id": "4:E",
      "icon_url": "https://i.imgur.com/dxqOJu3.png",
      "unique_stats": [
         {
            "id": "operatorpvp_rush_adrenalinerush",
            "name": "Adrenal Surge Bonus"
         }
      ]
   },
   "castle": {
      "name": "Castle",
      "safename": "castle",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SWAT",
      "country_code": "US",
      "roles": [
         "Anchor",
         "Secure"
      ],
      "side": "defender",
      "id": "2:2",
      "icon_url": "https://i.imgur.com/Fv8G4RW.png",
      "unique_stats": [
         {
            "id": "operatorpvp_castle_kevlarbarricadedeployed",
            "name": "Armor Panels Deployed"
         }
      ]
   },
   "capitao": {
      "name": "Capitão",
      "safename": "capitao",
      "year": "Y1S3",
      "health": 1,
      "armor": 3,
      "unit": "BOPE",
      "country_code": "BR",
      "roles": [
         "Area Denial",
         "Flank",
         "Front Line"
      ],
      "side": "attacker",
      "id": "2:8",
      "icon_url": "https://i.imgur.com/gBmMrMa.png",
      "unique_stats": [
         {
            "id": "operatorpvp_capitao_lethaldartkills",
            "name": "Kills with Asphyxiating Bolts"
         }
      ]
   },
   "ace": {
      "name": "Ace",
      "safename": "ace",
      "year": "Y5S2",
      "health": 2,
      "armor": 2,
      "unit": "NIGHTHAVEN",
      "country_code": "NO",
      "roles": [
         "Front Line",
         "Hard Breach"
      ],
      "side": "attacker",
      "id": "4:17",
      "icon_url": "https://i.imgur.com/GwWGSuu.png",
      "unique_stats": [
         {
            "id": "operatorpvp_ace_selmadetonate",
            "name": "S.E.L.M.A. Detonations"
         }
      ]
   },
   "amaru": {
      "name": "Amaru",
      "safename": "amaru",
      "year": "Y4S3",
      "health": 2,
      "armor": 2,
      "unit": "APCA",
      "country_code": "PE",
      "roles": [
         "Flank",
         "Front Line"
      ],
      "side": "attacker",
      "id": "2:16",
      "icon_url": "https://i.imgur.com/m5u47Mw.png",
      "unique_stats": [
         {
            "id": "operatorpvp_amaru_distancereeled",
            "name": "Total Distance Reeled"
         }
      ]
   },
   "zero": {
      "name": "Zero",
      "safename": "zero",
      "year": "Y5S3",
      "health": 2,
      "armor": 2,
      "unit": "ROS",
      "country_code": "US",
      "roles": [
         "Intel Denier",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "1:1B",
      "icon_url": "https://i.imgur.com/87LCqv1.png",
      "unique_stats": [
         {
            "id": "operatorpvp_zero_gadgetsdestroyed",
            "name": "Gadgets Destroyed by ARGUS Camera"
         }
      ]
   },
   "ash": {
      "name": "Ash",
      "safename": "ash",
      "year": "Y0S0",
      "health": 1,
      "armor": 3,
      "unit": "SWAT",
      "country_code": "US",
      "roles": [
         "Disable",
         "Flank",
         "Front Line",
         "Soft Breach"
      ],
      "side": "attacker",
      "id": "3:2",
      "icon_url": "https://i.imgur.com/ml0tMs3.png",
      "unique_stats": [
         {
            "id": "operatorpvp_ash_bonfirewallbreached",
            "name": "Destruction by Breaching Round"
         },
         {
            "id": "operatorpvp_ash_bonfirekill",
            "name": "Kills with Breaching Round"
         }
      ]
   },
   "twitch": {
      "name": "Twitch",
      "safename": "twitch",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "GIGN",
      "country_code": "FR",
      "roles": [
         "Back Line",
         "Disable",
         "Front Line",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "4:3",
      "icon_url": "https://i.imgur.com/jc5pPPK.png",
      "unique_stats": [
         {
            "id": "operatorpvp_twitch_gadgetdestroybyshockdrone",
            "name": "Gadgets Destroyed by Shock Drone"
         },
         {
            "id": "operatorpvp_twitch_shockdronekill",
            "name": "Kills with Shock Drone"
         }
      ]
   },
   "clash": {
      "name": "Clash",
      "safename": "clash",
      "year": "Y3S3",
      "health": 3,
      "armor": 1,
      "unit": "MPS",
      "country_code": "GB",
      "roles": [
         "Crowd Control",
         "Intel Gatherer",
         "Secure",
         "Shield"
      ],
      "side": "defender",
      "id": "3:10",
      "icon_url": "https://i.imgur.com/eogGdHx.png",
      "unique_stats": [
         {
            "id": "operatorpvp_clash_sloweddown",
            "name": "Enemies Killed While Slowed Down"
         }
      ]
   },
   "maestro": {
      "name": "Maestro",
      "safename": "maestro",
      "year": "Y3S2",
      "health": 3,
      "armor": 1,
      "unit": "G.I.S.",
      "country_code": "IT",
      "roles": [
         "Anchor",
         "Area Denial",
         "Intel Gatherer",
         "Secure"
      ],
      "side": "defender",
      "id": "2:F",
      "icon_url": "https://i.imgur.com/PQ8VBAF.png",
      "unique_stats": [
         {
            "id": "operatorpvp_barrage_killswithturret",
            "name": "Enemies Killed by Evil Eye"
         }
      ]
   },
   "lesion": {
      "name": "Lesion",
      "safename": "lesion",
      "year": "Y2S3",
      "health": 2,
      "armor": 2,
      "unit": "S.D.U",
      "country_code": "HK",
      "roles": [
         "Anchor",
         "Crowd Control",
         "Intel Gatherer",
         "Roam",
         "Trap"
      ],
      "side": "defender",
      "id": "3:B",
      "icon_url": "https://i.imgur.com/IvYOwrI.png",
      "unique_stats": [
         {
            "id": "operatorpvp_caltrop_enemy_affected",
            "name": "Enemies Poisoned by Gu Mine"
         }
      ]
   },
   "blackbeard": {
      "name": "Blackbeard",
      "safename": "blackbeard",
      "year": "Y1S2",
      "health": 2,
      "armor": 2,
      "unit": "NAVY SEAL",
      "country_code": "US",
      "roles": [
         "Back Line",
         "Covering Fire",
         "Shield"
      ],
      "side": "attacker",
      "id": "2:7",
      "icon_url": "https://i.imgur.com/BOAh5x8.png",
      "unique_stats": [
         {
            "id": "operatorpvp_blackbeard_gunshieldblockdamage",
            "name": "Bullets Stopped by Shield"
         }
      ]
   },
   "hibana": {
      "name": "Hibana",
      "safename": "hibana",
      "year": "Y1S4",
      "health": 1,
      "armor": 3,
      "unit": "S.A.T.",
      "country_code": "JP",
      "roles": [
         "Back Line",
         "Front Line",
         "Hard Breach"
      ],
      "side": "attacker",
      "id": "2:9",
      "icon_url": "https://i.imgur.com/aqOOm2R.png",
      "unique_stats": [
         {
            "id": "operatorpvp_hibana_detonate_projectile",
            "name": "X-KAIROS Pellets Detonated"
         }
      ]
   },
   "sledge": {
      "name": "Sledge",
      "safename": "sledge",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SAS",
      "country_code": "GB",
      "roles": [
         "Flank",
         "Soft Breach"
      ],
      "side": "attacker",
      "id": "4:1",
      "icon_url": "https://i.imgur.com/JXV80ZY.png",
      "unique_stats": [
         {
            "id": "operatorpvp_sledge_hammerhole",
            "name": "Destruction by Breaching Hammer"
         },
         {
            "id": "operatorpvp_sledge_hammerkill",
            "name": "Kills with Breaching Hammer"
         }
      ]
   },
   "kapkan": {
      "name": "Kapkan",
      "safename": "kapkan",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SPETSNAZ",
      "country_code": "RU",
      "roles": [
         "Trap"
      ],
      "side": "defender",
      "id": "4:4",
      "icon_url": "https://i.imgur.com/YHj9igl.png",
      "unique_stats": [
         {
            "id": "operatorpvp_kapkan_boobytrapkill",
            "name": "EDD Kills"
         },
         {
            "id": "operatorpvp_kapkan_boobytrapdeployed",
            "name": "EDD Deployed"
         }
      ]
   },
   "jackal": {
      "name": "Jackal",
      "safename": "jackal",
      "year": "Y2S1",
      "health": 2,
      "armor": 2,
      "unit": "G.E.O.",
      "country_code": "ES",
      "roles": [
         "Anti Roam",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "2:A",
      "icon_url": "https://i.imgur.com/cGBKp2a.png",
      "unique_stats": [
         {
            "id": "operatorpvp_cazador_assist_kill",
            "name": "Eyenox Tracking Assist"
         }
      ]
   },
   "iq": {
      "name": "IQ",
      "safename": "iq",
      "year": "Y0S0",
      "health": 1,
      "armor": 3,
      "unit": "GSG9",
      "country_code": "DE",
      "roles": [
         "Disable",
         "Flank",
         "Front Line",
         "Intel Gatherer"
      ],
      "side": "attacker",
      "id": "3:5",
      "icon_url": "https://i.imgur.com/M1NaKKv.png",
      "unique_stats": [
         {
            "id": "operatorpvp_iq_gadgetspotbyef",
            "name": "Gadgets Spotted by Electronics Detector"
         }
      ]
   },
   "bandit": {
      "name": "Bandit",
      "safename": "bandit",
      "year": "Y0S0",
      "health": 1,
      "armor": 3,
      "unit": "GSG9",
      "country_code": "DE",
      "roles": [
         "Anti Hard Breach",
         "Roam",
         "Secure"
      ],
      "side": "defender",
      "id": "5:5",
      "icon_url": "https://i.imgur.com/p6tWAW7.png",
      "unique_stats": [
         {
            "id": "operatorpvp_bandit_batterykill",
            "name": "Shock Wire Kills"
         }
      ]
   },
   "smoke": {
      "name": "Smoke",
      "safename": "smoke",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SAS",
      "country_code": "GB",
      "roles": [
         "Anchor",
         "Area Denial",
         "Secure"
      ],
      "side": "defender",
      "id": "2:1",
      "icon_url": "https://i.imgur.com/aodW3TF.png",
      "unique_stats": [
         {
            "id": "operatorpvp_smoke_poisongaskill",
            "name": "Poison Gas Kills"
         }
      ]
   },
   "doc": {
      "name": "Doc",
      "safename": "doc",
      "year": "Y0S0",
      "health": 3,
      "armor": 1,
      "unit": "GIGN",
      "country_code": "FR",
      "roles": [
         "Anchor",
         "Buff"
      ],
      "side": "defender",
      "id": "2:3",
      "icon_url": "https://i.imgur.com/19gitiC.png",
      "unique_stats": [
         {
            "id": "operatorpvp_doc_teammaterevive",
            "name": "Teammates Revived"
         },
         {
            "id": "operatorpvp_doc_selfrevive",
            "name": "Self Revives"
         },
         {
            "id": "operatorpvp_doc_hostagerevive",
            "name": "Hostages Revived"
         }
      ]
   },
   "warden": {
      "name": "Warden",
      "safename": "warden",
      "year": "Y4S2",
      "health": 2,
      "armor": 2,
      "unit": "SECRET SERVICE",
      "country_code": "US",
      "roles": [
         "Anchor",
         "Intel Denier"
      ],
      "side": "defender",
      "id": "2:14",
      "icon_url": "https://i.imgur.com/HqTIR7x.png",
      "unique_stats": [
         {
            "id": "operatorpvp_warden_killswithglasses",
            "name": "Kills While Using Glance"
         }
      ]
   },
   "ela": {
      "name": "Ela",
      "safename": "ela",
      "year": "Y2S4",
      "health": 1,
      "armor": 3,
      "unit": "G.R.O.",
      "country_code": "PL",
      "roles": [
         "Crowd Control",
         "Roam",
         "Trap"
      ],
      "side": "defender",
      "id": "2:C",
      "icon_url": "https://i.imgur.com/OwjSJNB.png",
      "unique_stats": [
         {
            "id": "operatorpvp_concussionmine_detonate",
            "name": "Grzmot Mines Detonated"
         }
      ]
   },
   "thermite": {
      "name": "Thermite",
      "safename": "thermite",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SWAT",
      "country_code": "US",
      "roles": [
         "Back Line",
         "Hard Breach"
      ],
      "side": "attacker",
      "id": "5:2",
      "icon_url": "https://i.imgur.com/o896oL9.png",
      "unique_stats": [
         {
            "id": "operatorpvp_thermite_reinforcementbreached",
            "name": "Reinforcements Breached by Thermal Charge"
         },
         {
            "id": "operatorpvp_thermite_chargekill",
            "name": "Kills with Thermal Charge"
         },
         {
            "id": "operatorpvp_thermite_chargedeployed",
            "name": "Thermal Charges Deployed"
         }
      ]
   },
   "pulse": {
      "name": "Pulse",
      "safename": "pulse",
      "year": "Y0S0",
      "health": 1,
      "armor": 3,
      "unit": "SWAT",
      "country_code": "US",
      "roles": [
         "Intel Gatherer",
         "Roam"
      ],
      "side": "defender",
      "id": "4:2",
      "icon_url": "https://i.imgur.com/Y2iDnWq.png",
      "unique_stats": [
         {
            "id": "operatorpvp_pulse_heartbeatspot",
            "name": "Heartbeats Spotted"
         },
         {
            "id": "operatorpvp_pulse_heartbeatassist",
            "name": "Heartbeat Scanner Assists"
         }
      ]
   },
   "valkyrie": {
      "name": "Valkyrie",
      "safename": "valkyrie",
      "year": "Y1S2",
      "health": 2,
      "armor": 2,
      "unit": "NAVY SEAL",
      "country_code": "US",
      "roles": [
         "Intel Gatherer",
         "Roam"
      ],
      "side": "defender",
      "id": "3:7",
      "icon_url": "https://i.imgur.com/xJHdqA3.png",
      "unique_stats": [
         {
            "id": "operatorpvp_valkyrie_camdeployed",
            "name": "Black Eye Cameras Deployed"
         }
      ]
   },
   "mute": {
      "name": "Mute",
      "safename": "mute",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SAS",
      "country_code": "GB",
      "roles": [
         "Anti Hard Breach",
         "Intel Denier",
         "Secure"
      ],
      "side": "defender",
      "id": "3:1",
      "icon_url": "https://i.imgur.com/peaKoO1.png",
      "unique_stats": [
         {
            "id": "operatorpvp_mute_gadgetjammed",
            "name": "Gadgets Jammed"
         },
         {
            "id": "operatorpvp_mute_jammerdeployed",
            "name": "Jammers Deployed"
         }
      ]
   },
   "thatcher": {
      "name": "Thatcher",
      "safename": "thatcher",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "SAS",
      "country_code": "GB",
      "roles": [
         "Back Line",
         "Disable"
      ],
      "side": "attacker",
      "id": "5:1",
      "icon_url": "https://i.imgur.com/BuEp8mz.png",
      "unique_stats": [
         {
            "id": "operatorpvp_thatcher_gadgetdestroywithemp",
            "name": "Gadgets Destroyed by EMP"
         }
      ]
   },
   "blitz": {
      "name": "Blitz",
      "safename": "blitz",
      "year": "Y0S0",
      "health": 2,
      "armor": 2,
      "unit": "GSG9",
      "country_code": "DE",
      "roles": [
         "Anti Roam",
         "Crowd Control",
         "Front Line",
         "Shield"
      ],
      "side": "attacker",
      "id": "2:5",
      "icon_url": "https://i.imgur.com/GxXncfV.png",
      "unique_stats": [
         {
            "id": "operatorpvp_blitz_flashedenemy",
            "name": "Enemies Blinded by Flash Shield"
         },
         {
            "id": "operatorpvp_blitz_flashfollowupkills",
            "name": "Post-flash follow up kills"
         },
         {
            "id": "operatorpvp_blitz_flashshieldassist",
            "name": "Post-flash assisted kills"
         }
      ]
   },
   "vigil": {
      "name": "Vigil",
      "safename": "vigil",
      "year": "Y2S4",
      "health": 1,
      "armor": 3,
      "unit": "707TH SMB",
      "country_code": "SK",
      "roles": [
         "Intel Denier",
         "Roam"
      ],
      "side": "defender",
      "id": "3:D",
      "icon_url": "https://i.imgur.com/WkqMEZ6.png",
      "unique_stats": [
         {
            "id": "operatorpvp_attackerdrone_diminishedrealitymode",
            "name": "Drones Deceived"
         }
      ]
   },
   "alibi": {
      "name": "Alibi",
      "safename": "alibi",
      "year": "Y3S2",
      "health": 1,
      "armor": 3,
      "unit": "G.I.S.",
      "country_code": "IT",
      "roles": [
         "Intel Denier",
         "Intel Gatherer",
         "Roam",
         "Trap"
      ],
      "side": "defender",
      "id": "3:F",
      "icon_url": "https://i.imgur.com/Phb6OUU.png",
      "unique_stats": [
         {
            "id": "operatorpvp_deceiver_revealedattackers",
            "name": "Enemies Tricked by Prisma"
         }
      ]
   }
}
